@@ -16,7 +16,7 @@ use Path::Tiny 'path';
 use Text::Diff ();
 use Try::Tiny qw( try catch finally );
 
-our $VERSION = '1.23'; # VERSION
+our $VERSION = '1.24'; # VERSION
 
 sub init {
     my $self = _new( shift, 'expect_no_root_dir' );
@@ -597,6 +597,14 @@ sub _build_execute_stack {
     my $prereqs       = { map { $_->{action} => $_->{prereqs} } @{ $self->_prereq_tree->{actions} } };
     my $state         = $self->_status_data->{actions};
 
+    if ( $type eq 'revert' ) {
+        my $postreqs;
+        for my $action ( keys %$prereqs ) {
+            push( @{ $postreqs->{$_} }, $action ) for ( @{ $prereqs->{$action} } );
+        }
+        $prereqs = $postreqs;
+    }
+
     my ( @execute_stack, $wraps );
     $seen_action //= {};
 
@@ -746,7 +754,7 @@ App::Dest - Deployment State Manager
 
 =head1 VERSION
 
-version 1.23
+version 1.24
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/dest.svg)](https://travis-ci.org/gryphonshafer/dest)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/dest/badge.png)](https://coveralls.io/r/gryphonshafer/dest)
@@ -1230,13 +1238,6 @@ Inside the C<data/stuff/deploy.pl> file, include the following line:
 
     # dest.prereq: db/schema
 
-Dependencies work in both deploy and revert files. Reverting the schema likely
-means dropping tables, so including a dependency to revert the data in those
-tables is probably just a waste of time. But if you really wanted to, you could
-optionally include in C<db/schema/revert.sql> the following line:
-
-    -- dest.prereq: data/stuff
-
 =head2 Other Developers
 
 Now let's say you invite a friend or coworker to the project. That person might
